@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-10-09 09:02:45
+@LastEditTime: 2021-10-13 19:31:31
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -29,7 +29,26 @@ class FrameBaseHandler(BaseApiHandler):
     """
     :description: 公共handler基类
     """
-    request_params = {}  # 请求参数
+
+    def prepare(self):
+        """
+        :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
+        :last_editors: HuangJianYi
+        """
+        if self.__class__.__name__ == "IndexHandler":
+            return
+        #获取请求参数
+        self._convert_request_params()
+        # 标记日志请求关联
+        dict_param = {}
+        dict_param["open_id"] = self.get_open_id()
+        if not dict_param["open_id"]:
+            dict_param["open_id"] = self.get_user_id()
+        dict_param["nick_name"] = self.get_user_nick()
+        dict_param["app_id"] = self.get_app_id()
+        if not dict_param["app_id"]:
+            dict_param["app_id"] = self.get_source_app_id()
+        self._build_http_log(dict_param)
 
     def options_async(self):
         self.response_json_success()
@@ -55,24 +74,6 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.json_loads(rep_str)
 
-    def base64_encrypt(self, source, encoding="utf-8"):
-        """
-        :Description: base64加密
-        :param source: 需加密的字符串
-        :return: 加密后的字符串
-        :last_editors: HuangJianYi
-        """
-        return CryptographyHelper.base64_encrypt(source, encoding)
-
-    def base64_encrypt(self, source, encoding="utf-8"):
-        """
-        :Description: base64解密
-        :param source: 需加密的字符串
-        :return: 解密后的字符串
-        :last_editors: HuangJianYi
-        """
-        return CryptographyHelper.base64_encrypt(source, encoding)
-
     def get_param(self, param_name, default="", strip=True):
         """
         :description: 二次封装获取参数
@@ -83,9 +84,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         param_ret = ""
 
-        if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-            if not self.request_params:
-                self.request_params = json.loads(self.request.body)
+        if self.request_params:
             param_ret = self.request_params[param_name] if self.request_params.__contains__(param_name) else ""
         else:
             param_ret = self.get_argument(param_name, default, strip=strip)
@@ -100,11 +99,7 @@ class FrameBaseHandler(BaseApiHandler):
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJianYi
         """
-        response_encrypt = config.get_value("response_encrypt", False)
-        if response_encrypt == True:
-            self.http_response("0" + self.base64_encrypt(self.json_dumps(rep_dic)))
-        else:
-            self.http_response(self.json_dumps(rep_dic))
+        self.http_response(self.json_dumps(rep_dic))
 
     def response_common(self, success=True, data=None, error_code="", error_message=""):
         """
@@ -120,7 +115,20 @@ class FrameBaseHandler(BaseApiHandler):
             data = data.__dict__
         template_value = {}
         template_value['success'] = success
-        template_value['data'] = data
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)
+        if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            dv = SevenHelper.get_random(16)
+            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
+            app_id = self.get_argument("source_app_id", "", strip=True)
+            if not app_id:
+                app_id = config.get_value("app_id")
+            password = app_id[0:10] + encrypt_key[0:6] if len(app_id) >= 10 and len(encrypt_key) >= 6 else ""
+            iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
+            template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
+            template_value['dv'] = dv
+        else:
+            template_value['data'] = data
         template_value['error_code'] = error_code
         template_value['error_message'] = error_message
 
@@ -133,11 +141,7 @@ class FrameBaseHandler(BaseApiHandler):
         if success == False:
             log_extra_dict["is_success"] = 0
 
-        response_encrypt = config.get_value("response_encrypt", False)
-        if response_encrypt == True:
-            self.http_reponse("0" + self.base64_encrypt(self.json_dumps(rep_dic)), log_extra_dict)
-        else:
-            self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)
+        self.http_reponse(self.json_dumps(rep_dic), log_extra_dict)
 
     def response_json_success(self, data=None):
         """
@@ -197,7 +201,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.get_now_datetime()
 
-    def create_order_id(self,ran=5):
+    def create_order_id(self, ran=5):
         """
         :description: 生成订单号
         :param ran：随机数位数，默认5位随机数（0-5）
@@ -219,16 +223,19 @@ class FrameBaseHandler(BaseApiHandler):
         result = False, ""
         if object_id and handler_name and app_id:
             request_param_dict = {}
-            if self.request.method!="GET" and self.request.body:
-                request_param_dict = json.loads(self.request.body)
-            else:
-                request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query,True).items()])
+            try:
+                if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                    request_param_dict = json.loads(self.request.body)
+                else:
+                    request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query, True).items()])
+            except:
+                pass
             sign = self.get_signature_md5(request_param_dict)
             if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
-    def get_signature_md5(self,request_param_dict,encrypt_key=""):
+    def get_signature_md5(self, request_param_dict, encrypt_key=""):
         """
         :description: 参数按照加密规则进行MD5加密
         :description: 签名规则 signature_md5= ((参数1=参数1值&参数2=参数2值&signature_stamp={signature_stamp}))+密钥)进行Md5加密转小写，参数顺序按照字母表的顺序排列
@@ -243,7 +250,7 @@ class FrameBaseHandler(BaseApiHandler):
             if k == "signature_md5":
                 continue
             request_sign_params[k] = v.replace(" ", "_seven_").replace("(", "_seven1_").replace(")", "_seven2_")
-        request_params_sorted = sorted(request_sign_params.items(),key=lambda e: e[0],reverse=False)
+        request_params_sorted = sorted(request_sign_params.items(), key=lambda e: e[0], reverse=False)
         request_message = "&".join(k + "=" + CodingHelper.url_encode(v) for k, v in request_params_sorted)
         request_message = request_message.replace("_seven_", "%20").replace("_seven1_", "(").replace("_seven2_", ")").replace("%27", "'")
         # MD5摘要
@@ -322,52 +329,68 @@ class FrameBaseHandler(BaseApiHandler):
         self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
         self.set_header("Access-Control-Allow-Credentials", "true")
 
-
-class ClientBaseHandler(FrameBaseHandler):
-
-    """
-    :description: 客户端handler基类
-    """
-
-    device_info_dict = {}  # 头部参数
-
-    def prepare(self):
+    def _convert_request_params(self):
         """
-        :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
+        :Description: 转换请求参数
         :last_editors: HuangJianYi
         """
-        if self.__class__.__name__ == "IndexHandler":
-            return
+        invoke_result_data = InvokeResultData()
+        self.request_params = {}
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #服务端加密类型 0-无，1-aes加密，2-md5加密
+        if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
+            app_id = self.get_argument("source_app_id", "", strip=True)
+            if not app_id:
+                app_id = config.get_value("app_id")
+            password = app_id[0:10] + encrypt_key[0:6] if len(app_id) >= 10 and len(encrypt_key) >= 6 else ""
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                try:
+                    json_params = json.loads(self.request.body)
+                    if json_params:
+                        for field in json_params:
+                            self.request_params[field] = json_params[field]
+                        par = json_params["par"] if json_params.__contains__("par") else ""
+                        dv = json_params["dv"] if json_params.__contains__("dv") else ""
+                        iv = app_id[0:10] + str(json_params["dv"])[0:6] if len(str(json_params["dv"])) >= 6 else ""
+                        body_params = json.loads(CryptographyHelper.aes_decrypt(str(json_params["par"]), password, iv))
+                        for field in body_params:
+                            self.request_params[field] = body_params[field]
+                except:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "error"
+                    invoke_result_data.error_message = "参数解析错误"
+                    return invoke_result_data
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_argument(field, "", strip=True)
+                if "par" in self.request.arguments and "dv" in self.request.arguments:
+                    par = self.get_argument("par", "", strip=True)
+                    dv = self.get_argument("dv", "", strip=True)
+                    iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
+                    try:
+                        body_params = json.loads(CryptographyHelper.aes_decrypt(par, password, iv))
+                        for field in body_params:
+                            self.request_params[field] = body_params[field]
+                    except:
+                        invoke_result_data.success = False
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = "参数解析错误"
+                        return invoke_result_data
+        else:
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                try:
+                    json_params = json.loads(self.request.body)
+                except:
+                    pass
+                if json_params:
+                    for field in json_params:
+                        self.request_params[field] = json_params[field]
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_argument(field, "", strip=True)
 
-        dict_param = {}
-        dict_param["open_id"] = self.get_open_id()
-        if not dict_param["open_id"]:
-            dict_param["open_id"] = self.get_user_id()
-        dict_param["nick_name"] = self.get_user_nick()
-        dict_param["app_id"] = self.get_app_id()
-        if not dict_param["app_id"]:
-            dict_param["app_id"] = self.get_source_app_id()
-
-        try:
-            # 标记日志请求关联
-            self._build_http_log(dict_param)
-
-            # 将设备信息字符串转为字典类型
-            clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
-            if clientheaderinfo_string:
-                self.device_info_dict = self.get_device_info_dict(clientheaderinfo_string)
-
-            if dict_param["open_id"]:
-                # 频繁请求校验
-                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_param["app_id"], dict_param["open_id"])
-                if is_continue_request:
-                    return self.response_json_error("error", error_message)
-
-                #每分钟流量UV计数,用于登录接口限制登录
-                self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
-
-        except Exception as ex:
-            self.logging_link_error("【客户端handler基类】" + str(ex))
+        return invoke_result_data
 
     def get_user_nick(self):
         """
@@ -402,7 +425,7 @@ class ClientBaseHandler(FrameBaseHandler):
         """
         user_id = int(self.get_param("tb_user_id", 0))
         if user_id == 0:
-            user_id = int(self.get_param("user_id",0))
+            user_id = int(self.get_param("user_id", 0))
         return user_id
 
     def get_source_app_id(self):
@@ -428,7 +451,7 @@ class ClientBaseHandler(FrameBaseHandler):
         if app_id == "":
             plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
             user_nick = self.get_user_nick()
-            if user_nick and plat_type ==1:
+            if user_nick and plat_type == 1:
                 store_user_nick = user_nick.split(':')[0]
                 if store_user_nick:
                     app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", field="app_id", params=store_user_nick)
@@ -436,37 +459,7 @@ class ClientBaseHandler(FrameBaseHandler):
                         app_id = app_info_dict["app_id"]
         return app_id
 
-    def get_online_url(self, act_id, app_id, module_id=0):
-        """
-        :description: 获取online_url
-        :param act_id:活动标识
-        :param app_id:应用标识
-        :param module_id:模块标识
-        :param page:跳转的首页地址pages/index/index
-        :return str
-        :last_editors: HuangJianYi
-        """
-        page_index = ""
-        page = config.get_value("page_index")
-        if page:
-            page_index = "&page=" + CodingHelper.url_encode(page)
-        query = CodingHelper.url_encode(f"actid={act_id}")
-        if module_id > 0:
-            query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
-        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
-        return online_url
-
-    def get_live_url(self, app_id):
-        """
-        :description: 获取live_url
-        :param app_id:应用标识
-        :return str
-        :last_editors: HuangJianYi
-        """
-        live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
-        return live_url
-
-    def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="",operate_user_name=""):
+    def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name=""):
         """
         :description: 创建操作日志
         :param operation_type：操作类型：1-add，2-update，3-delete
@@ -510,6 +503,100 @@ class ClientBaseHandler(FrameBaseHandler):
 
         operation_log_model.add_entity(operation_log)
 
+
+class ClientBaseHandler(FrameBaseHandler):
+    """
+    :description: 客户端handler基类
+    """
+
+    def prepare(self):
+        """
+        :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
+        :last_editors: HuangJianYi
+        """
+        if self.__class__.__name__ == "IndexHandler":
+            return
+        #获取请求参数
+        invoke_result_data = self._convert_request_params()
+        if invoke_result_data.success == False:
+            self.request_code = UUIDHelper.get_uuid()
+            self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            self.finish()
+            return
+
+        dict_param = {}
+        dict_param["open_id"] = self.get_open_id()
+        if not dict_param["open_id"]:
+            dict_param["open_id"] = self.get_user_id()
+        dict_param["nick_name"] = self.get_user_nick()
+        dict_param["app_id"] = self.get_app_id()
+        if not dict_param["app_id"]:
+            dict_param["app_id"] = self.get_source_app_id()
+
+        # 标记日志请求关联
+        self._build_http_log(dict_param)
+
+        try:
+            # 将设备信息字符串转为字典类型
+            self.device_info_dict = {}
+            clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
+            if clientheaderinfo_string:
+                self.device_info_dict = self.get_device_info_dict(clientheaderinfo_string)
+
+            # 验证超时 10分钟过期
+            client_encrypt_type = config.get_value("client_encrypt_type", 0)
+            server_encrypt_type = config.get_value("server_encrypt_type", 0)
+            if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+                now_time = TimeHelper.get_now_timestamp(True)
+                if self.request_params.__contains__("timestamp") and (now_time - int(self.request_params["timestamp"]) > int(1000 * 60 * 10)):
+                    self.response_json_error("timestamp", "超时操作")
+                    self.finish()
+                    return
+
+            # 频繁请求校验
+            if dict_param["open_id"] and "/client/" in self.request.uri:
+                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_param["app_id"], dict_param["open_id"])
+                if is_continue_request:
+                    self.response_json_error("error", error_message)
+                    self.finish()
+                    return
+
+                #每分钟流量UV计数,用于登录接口限制登录
+                self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
+
+        except Exception as ex:
+            self.logging_link_error("【客户端handler基类】" + traceback.format_exc())
+
+    def get_online_url(self, act_id, app_id, module_id=0):
+        """
+        :description: 获取online_url
+        :param act_id:活动标识
+        :param app_id:应用标识
+        :param module_id:模块标识
+        :param page:跳转的首页地址pages/index/index
+        :return str
+        :last_editors: HuangJianYi
+        """
+        page_index = ""
+        page = config.get_value("page_index")
+        if page:
+            page_index = "&page=" + CodingHelper.url_encode(page)
+        query = CodingHelper.url_encode(f"actid={act_id}")
+        if module_id > 0:
+            query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
+        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
+        return online_url
+
+    def get_live_url(self, app_id):
+        """
+        :description: 获取live_url
+        :param app_id:应用标识
+        :return str
+        :last_editors: HuangJianYi
+        """
+        live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
+        return live_url
+
     def get_device_info_dict(self, device_str):
         """
         :description: 获取头部参数字典
@@ -519,16 +606,16 @@ class ClientBaseHandler(FrameBaseHandler):
         device_info_dict = {}
         info_model = parse_qs(device_str)
         device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
-        device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0]) # 渠道标识
-        device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0]) # 高度
-        device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0]) # 宽度
+        device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0])  # 渠道标识
+        device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0])  # 高度
+        device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0])  # 宽度
         device_info_dict["version"] = "" if "version" not in info_model.keys() else info_model["version"][0]  # 客户端版本号
         device_info_dict["app_version"] = "" if "app_version" not in info_model.keys() else info_model["app_version"][0]  # 小程序版本号
-        device_info_dict["net"] = "" if "net" not in info_model.keys() else info_model["net"][0]   # 网络
+        device_info_dict["net"] = "" if "net" not in info_model.keys() else info_model["net"][0]  # 网络
         device_info_dict["model_p"] = "" if "model" not in info_model.keys() else info_model["model"][0]  # 机型
         device_info_dict["lang"] = "" if "lang" not in info_model.keys() else info_model["lang"][0]  #语言
         device_info_dict["ver_no"] = "" if "ver_no" not in info_model.keys() else info_model["ver_no"][0]  #接口版本号
-        device_info_dict["signature_stamp"] = 0 if "signature_stamp" not in info_model.keys() else int(info_model["signature_stamp"][0]) # 时间搓秒
+        device_info_dict["timestamp"] = 0 if "timestamp" not in info_model.keys() else int(info_model["timestamp"][0])  # 时间搓毫秒
         device_info_dict["signature_md5"] = "" if "signature_md5" not in info_model.keys() else info_model["signature_md5"][0]  # 签名md5
         return device_info_dict
 
@@ -547,7 +634,6 @@ def filter_check_params(must_params=None):
     """
     def check_params(handler):
         def wrapper(self, **args):
-            self.request_params = {}
             finally_must_params = must_params
             if hasattr(self, "must_params"):
                 finally_must_params = self.must_params
@@ -555,24 +641,13 @@ def filter_check_params(must_params=None):
                 must_array = finally_must_params.split(",")
             if type(finally_must_params) == list:
                 must_array = finally_must_params
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                json_params = {}
-                try:
-                    json_params = json.loads(self.request.body)
-                except:
-                    self.response_json_error("ParamError", "参数错误,缺少必传参数")
-                    return
-                if json_params:
-                    for field in json_params:
-                        self.request_params[field] = json_params[field]
-            else:
-                for field in self.request.arguments:
-                    self.request_params[field] = self.get_param(field)
+
             if finally_must_params:
                 for must_param in must_array:
                     if not must_param in self.request_params or self.request_params[must_param] == "":
-                        self.response_json_error("ParamError", "参数错误,缺少必传参数")
+                        self.response_json_error("param_error", "参数错误,缺少必传参数")
                         return
+
             return handler(self, **args)
 
         return wrapper
@@ -589,7 +664,7 @@ def filter_check_head_sign(is_check=True, no_check_params=None):
     """
     def check_head(handler):
         def wrapper(self, **args):
-            encrypt_key = config.get_value("encrypt_key", "3924e337a476475e95b2b341eaba8c1c")
+            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
             is_check_head = config.get_value("is_check_head", False)
             if is_check_head == False:
                 is_check = False
@@ -610,8 +685,8 @@ def filter_check_head_sign(is_check=True, no_check_params=None):
                         device_info_dict = self.device_info_dict(clientheaderinfo_string)
                         # 验证签名超时 10分钟过期
                         now_time = TimeHelper.get_now_timestamp(True)
-                        if now_time - device_info_dict["signature_stamp"] > int(1000 * 60 * 10):
-                            return self.response_json_error("signature_stamp", "超时操作")
+                        if now_time - device_info_dict["timestamp"] > int(1000 * 60 * 10):
+                            return self.response_json_error("timestamp", "超时操作")
                         # 验证是否有头部信息签名
                         if not device_info_dict.__contains__("signature_md5"):
                             return self.response_json_error("signature_md5", "缺少参数signature_md5")
@@ -624,7 +699,7 @@ def filter_check_head_sign(is_check=True, no_check_params=None):
                     else:
                         return self.response_json_error("no_device_info", "没有提交设备信息")
                 except Exception as ex:
-                    self.logging_link_error("【头部校验异常】" + str(ex))
+                    self.logging_link_error("【头部校验异常】" + traceback.format_exc())
                     return self.response_json_error("error", "头部验证失败")
 
             return handler(self, **args)
@@ -643,9 +718,10 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
     """
     def check_params(handler):
         def wrapper(self, **args):
-            encrypt_key = config.get_value("encrypt_key", "3924e337a476475e95b2b341eaba8c1c")
-            is_check_params = config.get_value("is_check_params", False)
-            if is_check_params == False:
+            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
+            client_encrypt_type = config.get_value("client_encrypt_type", 0)
+            server_encrypt_type = config.get_value("server_encrypt_type", 0)
+            if ("/server/" in self.request.uri and server_encrypt_type != 2) or ("/client/" in self.request.uri and client_encrypt_type != 2):
                 is_check = False
             else:
                 is_check = True
@@ -659,19 +735,22 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
                         no_check_array = []
                     # 验证参数
                     request_param_dict = {}
-                    if self.request.method != "GET" and self.request.body:
-                        request_param_dict = json.loads(self.request.body)
-                    else:
-                        request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query, True).items() if not k in no_check_array])
+                    try:
+                        if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                            request_param_dict = json.loads(self.request.body)
+                        else:
+                            request_param_dict = dict([(k, v[0]) for k, v in parse_qs(self.request.query, True).items() if not k in no_check_array])
+                    except:
+                        pass
                     if not request_param_dict.__contains__("param_signature_md5"):
-                        return self.client_reponse_json_error("signature_fail", "缺少参数param_signature_md5")
+                        return self.response_json_error("signature_fail", "缺少参数param_signature_md5")
                     check_request_signature_md5 = self.get_signature_md5(request_param_dict, encrypt_key)
                     param_signature_md5 = request_param_dict["param_signature_md5"].lower()
                     if check_request_signature_md5 != param_signature_md5:
-                        return self.client_reponse_json_error("signature_fail", "参数签名验证失败")
+                        return self.response_json_error("signature_fail", "参数签名验证失败")
 
                 except Exception as ex:
-                    self.logging_link_error("【请求参数校验异常】" + str(ex))
+                    self.logging_link_error("【请求参数校验异常】" + traceback.format_exc())
                     return self.response_json_error("error", "请求参数验证失败")
 
             return handler(self, **args)
