@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-09-29 11:51:17
+@LastEditTime: 2021-10-13 19:03:19
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -76,6 +76,19 @@ class QueueUpHelper:
             zset_name += "_" + str(app_id)
         return zset_name
 
+    @classmethod
+    def _get_popdate_hash_name(self, app_id):
+        """
+        :description: 办理中的用户退出队列的时间列表名称
+        :param app_id：应用标识
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        hash_name = "queueup_popdate_list"
+        if app_id:
+            hash_name += "_" + str(app_id)
+        return hash_name
+
     @classmethod
     def _get_queue_no(self, app_id, queue_name):
         """
@@ -214,6 +227,8 @@ class QueueUpHelper:
                 hash_value["info_json"] = info_dict
 
                 queue_index = int(redis_init.zrank(zset_name, data)) + 1
+                if queue_index == 1:
+                    redis_init.hdel(self._get_popdate_hash_name(app_id), zset_name)
                 #添加排队信息
                 hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
@@ -236,13 +251,27 @@ class QueueUpHelper:
                 invoke_result_data.error_message = "该用户已在队列中,请勿重复排队"
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【加入排队】" + str(ex))
+            self.logger_error.error("【加入排队】" + traceback.format_exc())
             SevenHelper.redis_release_lock(acquire_lock_name, identifier)
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "排队失败,请稍后再来"
             return invoke_result_data
 
+    @classmethod
+    def _set_last_pop_date(self,app_id, redis_init, hash_key):
+        """
+        :description: 设置办理中的用户退出队列的时间
+        :param app_id：应用标识
+        :param redis_init：redis_init
+        :param hash_key：hash_key
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        hash_name = self._get_popdate_hash_name(app_id)
+        redis_init.hset(hash_name, hash_key, str(TimeHelper.get_now_timestamp()))
+        redis_init.expire(hash_name, 7 * 24 * 3600)
+
     @classmethod
     def pop(self, app_id, queue_name, user_id):
         """
@@ -268,6 +297,8 @@ class QueueUpHelper:
             data = str(user_id)
             redis_init = SevenHelper.redis_init()
             if redis_init.zscore(zset_name, data):
+                if int(redis_init.zrank(zset_name, data)) + 1 == 1:
+                    self._set_last_pop_date(app_id,redis_init, zset_name)
                 redis_init.zrem(zset_name, data)
                 redis_init.zincrby(self._get_user_zset_name(app_id), -1, data)
                 redis_init.hdel(self._get_user_hash_name(app_id), f"userid_{data}_queuename_{queue_name}")
@@ -278,7 +309,7 @@ class QueueUpHelper:
                 invoke_result_data.error_message = "未查到该用户的排队情况,请先排队"
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【退出排队】" + str(ex))
+            self.logger_error.error("【退出排队】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "退出排队失败"
@@ -333,14 +364,21 @@ class QueueUpHelper:
                                 if now_timestamp > first_end_timestamp + (i * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
                             else:
-                                if now_timestamp > hash_value["queue_timestamp"] + ((i + 1) * int(config.get_value("queue_confirm_time", 8))):
+                                pop_timestamp = redis_init.hget(self._get_popdate_hash_name(app_id), zset_name)
+                                if pop_timestamp:
+                                    pop_timestamp = int(pop_timestamp)
+                                else:
+                                    pop_timestamp = hash_value["queue_timestamp"]
+                                if now_timestamp > pop_timestamp + ((i + 1) * int(config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
+                                    
                         if is_delete == True:
+                            self._set_last_pop_date(app_id, redis_init, zset_name)
                             redis_init.hdel(hash_name, f"userid_{data}_queuename_{queue_name}")
                             redis_init.zrem(zset_name, data)
                             redis_init.zincrby(self._get_user_zset_name(app_id), -1, data)
             except Exception as ex:
-                self.logger_error.error("【删除未操作的排队信息】" + str(ex))
+                self.logger_error.error("【删除未操作的排队信息】" + traceback.format_exc())
 
     @classmethod
     def pop_by_user_id(self, app_id, user_id, progress_status=1):
@@ -413,7 +451,7 @@ class QueueUpHelper:
                 invoke_result_data.error_message = "未查到排队情况,请先排队"
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【查询某用户排队情况】" + str(ex))
+            self.logger_error.error("【查询某用户排队情况】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "未查到排队情况,请先排队"
@@ -442,7 +480,7 @@ class QueueUpHelper:
                     invoke_result_data.data.append(query_invoke_result_data.data)
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【批量查询某用户排队情况】" + str(ex))
+            self.logger_error.error("【批量查询某用户排队情况】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "未查到排队情况,请先排队"
@@ -466,7 +504,7 @@ class QueueUpHelper:
                 invoke_result_data.data.append(query_invoke_result_data.data)
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【批量查询排队情况】" + str(ex))
+            self.logger_error.error("【批量查询排队情况】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "未查到排队情况"
@@ -510,7 +548,7 @@ class QueueUpHelper:
                 redis_init.hset(hash_name, hash_key, SevenHelper.json_dumps(hash_value))
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【更新可操作时间】" + str(ex))
+            self.logger_error.error("【更新可操作时间】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "更新可操作时间失败"
@@ -580,7 +618,7 @@ class QueueUpHelper:
                 invoke_result_data.error_message = "未查到排队情况,请先排队"
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【签到操作】" + str(ex))
+            self.logger_error.error("【签到操作】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "未查到排队情况,请先排队"
