@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-10-09 09:19:05
+@LastEditTime: 2021-10-12 11:53:31
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -267,33 +267,29 @@ class SevenHelper:
             return '%.2f' % float(size / 1000000000000) + 'TB'
 
     @classmethod
-    def get_random(self, length, num=1):
+    def get_random(self,length):
         """
         :description: 获取随机数
         :param length：长度
-        :param num：个数
         :return: str
         :last_editors: HuangJianYi
         """
         result = ""
-        for x in range(num):
-            s = ""
-            for i in range(length):
-                # n=1 生成数字  n=2 生成字母
-                n = random.randint(1, 2)
-                if n == 1:
-                    numb = random.randint(0, 9)
-                    s += str(numb)
+        for i in range(length):
+            # n=1 生成数字  n=2 生成字母
+            n = random.randint(1, 2)
+            if n == 1:
+                numb = random.randint(0, 9)
+                result += str(numb)
+            else:
+                nn = random.randint(1, 2)
+                cc = random.randint(1, 26)
+                if nn == 1:
+                    numb = chr(64 + cc)
+                    result += numb
                 else:
-                    nn = random.randint(1, 2)
-                    cc = random.randint(1, 26)
-                    if nn == 1:
-                        numb = chr(64 + cc)
-                        s += numb
-                    else:
-                        numb = chr(96 + cc)
-                        s += numb
-            result += s
+                    numb = chr(96 + cc)
+                    result += numb
         return result
 
     @classmethod
@@ -438,7 +434,7 @@ class SevenHelper:
         results = re.findall('\[em_(.*?)\]', text_str)
         if results:
             for item in results:
-                text_str = text_str.replace("[em_{0}]".format(item), CryptographyHelper.base64_encrypt(item, "utf-8"))
+                text_str = text_str.replace("[em_{0}]".format(item), CryptographyHelper.base64_decrypt(item))
         return text_str
 
     @classmethod
