@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-10-08 14:18:36
+@LastEditTime: 2021-10-12 17:53:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -72,10 +72,10 @@ class WeChatHelper:
             redis_init.set(f"{app_id}_wechat_sessionkey:{open_id}", session_key, ex=60 * 60)
             return respone_data
         except Exception as ex:
-            self.logger_error.error("【code2_session】" + str(ex) + ":" + str(respone.text))
+            self.logger_error.error("【code2_session】" + traceback.format_exc() + ":" + str(respone.text))
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = str(ex)
+            invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
     @classmethod
@@ -110,10 +110,10 @@ class WeChatHelper:
             invoke_result_data.data = str(respone_data["access_token"])
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【get_access_token】" + str(ex) + ":" + str(respone.text))
+            self.logger_error.error("【get_access_token】" + traceback.format_exc() + ":" + str(respone.text))
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = str(ex)
+            invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
     @classmethod
@@ -142,7 +142,7 @@ class WeChatHelper:
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error("【decrypt_data_by_code】" + str(ex))
+            self.logger_error.error("【decrypt_data_by_code】" + traceback.format_exc())
         return data
 
     @classmethod
@@ -163,7 +163,7 @@ class WeChatHelper:
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error("【decrypt_data】" + str(ex))
+            self.logger_error.error("【decrypt_data】" + traceback.format_exc())
         return data
 
     @classmethod
@@ -388,7 +388,7 @@ class WeChatPayRequest(object):
             invoke_result_data.data = response_data
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【查询订单】" + str(ex) + ":" + str(request_xml))
+            self.logger_error.error("【查询订单】" + traceback.format_exc() + ":" + str(request_xml))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "查询订单出现异常"
@@ -423,7 +423,7 @@ class WeChatPayRequest(object):
             invoke_result_data.data = response_data
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【关闭订单】" + str(ex) + ":" + str(request_xml))
+            self.logger_error.error("【关闭订单】" + traceback.format_exc() + ":" + str(request_xml))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "关闭订单出现异常"
@@ -525,7 +525,7 @@ class WeChatPayRequest(object):
             invoke_result_data.data = response_data
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【查询退款单】" + str(ex) + ":" + str(request_xml))
+            self.logger_error.error("【查询退款单】" + traceback.format_exc() + ":" + str(request_xml))
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "查询退款单出现异常"
