@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-09-14 19:48:13
+@LastEditTime: 2021-09-26 12:20:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -202,7 +202,7 @@ class AppBaseModel():
             app_info.access_token = access_token
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
-            app_info_model.update_entity(app_info,"expiration_date")
+            app_info_model.update_entity(app_info,"expiration_date,access_token")
 
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
