@@ -2,12 +2,12 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2021-09-07 18:37:43
+@LastEditTime: 2021-09-29 10:51:11
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
 
-from enum import Enum, unique
+from enum import Enum
 
 class OperationType(Enum):
     """
@@ -20,7 +20,7 @@ class OperationType(Enum):
 
 class TaskType(Enum):
     """
-    docstring：任务类型 业务的自定义任务类型从200起
+    docstring：任务类型 业务的自定义任务类型从201起
     """
     # 掌柜有礼、免费领取、新人有礼，格式：{"reward_value":0,"asset_object_id":""}  字段说明：reward_value:奖励值 asset_object_id:资产对象标识
     free_gift = 1
