@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-27 11:28:25
+@LastEditTime: 2021-10-12 17:54:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -443,7 +443,7 @@ class OrderBaseModel(FrameBaseModel):
                 return invoke_result_data
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.context.logging_link_error("create_prize_order:" + str(ex))
+            self.context.logging_link_error("create_prize_order:" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起,下单失败"
@@ -610,7 +610,7 @@ class OrderBaseModel(FrameBaseModel):
                                 pay_num = pay_num + 1
                                 buy_num = buy_num + order['num']          
                         except Exception as ex:
-                            self.context.logging_link_info(str(order) + "【同步淘宝支付订单】" + str(ex))
+                            self.context.logging_link_info(str(order) + "【同步淘宝支付订单】" + traceback.format_exc())
                             continue
                     if len(tao_pay_order_list) > 0:
                         result = TaoPayOrderModel(context=self.context).add_list(tao_pay_order_list)
@@ -655,7 +655,7 @@ class OrderBaseModel(FrameBaseModel):
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "没有订单"  
         except Exception as ex:
-            self.context.logging_link_error("【同步淘宝支付订单】" + str(ex))
+            self.context.logging_link_error("【同步淘宝支付订单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"    
